# Changelog

## 0.2.0 (2022-07-11)

* Add alias options in config.
* Add review of previous unfinished tasks on new day.
* Add status command.
* Add config command.
* Pretty print click exceptions.

## 0.1.1 (2022-07-05)

* Fix update status without passing task id as argument.

## 0.1.0 (2022-07-05)

* Initial release.
* Manage daily tasks with status.
* Copy task details to clipboard.
